# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: openolt.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='openolt.proto',
  package='openolt',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\ropenolt.proto\x12\x07openolt\x1a\x11\x61nnotations.proto\"\xe9\x03\n\nIndication\x12)\n\x07olt_ind\x18\x01 \x01(\x0b\x32\x16.openolt.OltIndicationH\x00\x12+\n\x08intf_ind\x18\x02 \x01(\x0b\x32\x17.openolt.IntfIndicationH\x00\x12\x34\n\rintf_oper_ind\x18\x03 \x01(\x0b\x32\x1b.openolt.IntfOperIndicationH\x00\x12\x32\n\x0conu_disc_ind\x18\x04 \x01(\x0b\x32\x1a.openolt.OnuDiscIndicationH\x00\x12)\n\x07onu_ind\x18\x05 \x01(\x0b\x32\x16.openolt.OnuIndicationH\x00\x12+\n\x08omci_ind\x18\x06 \x01(\x0b\x32\x17.openolt.OmciIndicationH\x00\x12,\n\x07pkt_ind\x18\x07 \x01(\x0b\x32\x19.openolt.PacketIndicationH\x00\x12-\n\nport_stats\x18\x08 \x01(\x0b\x32\x17.openolt.PortStatisticsH\x00\x12-\n\nflow_stats\x18\t \x01(\x0b\x32\x17.openolt.FlowStatisticsH\x00\x12-\n\talarm_ind\x18\n \x01(\x0b\x32\x18.openolt.AlarmIndicationH\x00\x42\x06\n\x04\x64\x61ta\"\xef\x05\n\x0f\x41larmIndication\x12)\n\x07los_ind\x18\x01 \x01(\x0b\x32\x16.openolt.LosIndicationH\x00\x12\x36\n\x0e\x64ying_gasp_ind\x18\x02 \x01(\x0b\x32\x1c.openolt.DyingGaspIndicationH\x00\x12\x34\n\ronu_alarm_ind\x18\x03 \x01(\x0b\x32\x1b.openolt.OnuAlarmIndicationH\x00\x12\x44\n\x14onu_startup_fail_ind\x18\x04 \x01(\x0b\x32$.openolt.OnuStartupFailureIndicationH\x00\x12\x45\n\x16onu_signal_degrade_ind\x18\x05 \x01(\x0b\x32#.openolt.OnuSignalDegradeIndicationH\x00\x12\x46\n\x17onu_drift_of_window_ind\x18\x06 \x01(\x0b\x32#.openolt.OnuDriftOfWindowIndicationH\x00\x12\x44\n\x11onu_loss_omci_ind\x18\x07 \x01(\x0b\x32\'.openolt.OnuLossOfOmciChannelIndicationH\x00\x12\x44\n\x14onu_signals_fail_ind\x18\x08 \x01(\x0b\x32$.openolt.OnuSignalsFailureIndicationH\x00\x12\x43\n\x0conu_tiwi_ind\x18\t \x01(\x0b\x32+.openolt.OnuTransmissionInterferenceWarningH\x00\x12J\n\x17onu_activation_fail_ind\x18\n \x01(\x0b\x32\'.openolt.OnuActivationFailureIndicationH\x00\x12I\n\x18onu_processing_error_ind\x18\x0b \x01(\x0b\x32%.openolt.OnuProcessingErrorIndicationH\x00\x42\x06\n\x04\x64\x61ta\"#\n\rOltIndication\x12\x12\n\noper_state\x18\x01 \x01(\t\"5\n\x0eIntfIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x12\n\noper_state\x18\x02 \x01(\t\"R\n\x11OnuDiscIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12,\n\rserial_number\x18\x02 \x01(\x0b\x32\x15.openolt.SerialNumber\"\x87\x01\n\rOnuIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x12\n\noper_state\x18\x03 \x01(\t\x12\x13\n\x0b\x61\x64min_state\x18\x05 \x01(\t\x12,\n\rserial_number\x18\x04 \x01(\x0b\x32\x15.openolt.SerialNumber\"G\n\x12IntfOperIndication\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07intf_id\x18\x02 \x01(\x07\x12\x12\n\noper_state\x18\x03 \x01(\t\">\n\x0eOmciIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0b\n\x03pkt\x18\x03 \x01(\x0c\"\x89\x01\n\x10PacketIndication\x12\x11\n\tintf_type\x18\x05 \x01(\t\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x12\n\ngemport_id\x18\x02 \x01(\x07\x12\x0f\n\x07\x66low_id\x18\x03 \x01(\x07\x12\x0f\n\x07port_no\x18\x06 \x01(\x07\x12\x0e\n\x06\x63ookie\x18\x07 \x01(\x06\x12\x0b\n\x03pkt\x18\x04 \x01(\x0c\"\x1c\n\tInterface\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\"(\n\tHeartbeat\x12\x1b\n\x13heartbeat_signature\x18\x01 \x01(\x07\"a\n\x03Onu\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12,\n\rserial_number\x18\x03 \x01(\x0b\x32\x15.openolt.SerialNumber\x12\x0b\n\x03pir\x18\x04 \x01(\x07\"7\n\x07OmciMsg\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0b\n\x03pkt\x18\x03 \x01(\x0c\"J\n\tOnuPacket\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0f\n\x07port_no\x18\x04 \x01(\x07\x12\x0b\n\x03pkt\x18\x03 \x01(\x0c\",\n\x0cUplinkPacket\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0b\n\x03pkt\x18\x02 \x01(\x0c\"\x88\x07\n\nDeviceInfo\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\r\n\x05model\x18\x02 \x01(\t\x12\x18\n\x10hardware_version\x18\x03 \x01(\t\x12\x18\n\x10\x66irmware_version\x18\x04 \x01(\t\x12\x11\n\tdevice_id\x18\x10 \x01(\t\x12\x1c\n\x14\x64\x65vice_serial_number\x18\x11 \x01(\t\x12\x11\n\tpon_ports\x18\x0c \x01(\x07\x12\x12\n\ntechnology\x18\x05 \x01(\t\x12\x14\n\x0conu_id_start\x18\x06 \x01(\x07\x12\x12\n\nonu_id_end\x18\x07 \x01(\x07\x12\x16\n\x0e\x61lloc_id_start\x18\x08 \x01(\x07\x12\x14\n\x0c\x61lloc_id_end\x18\t \x01(\x07\x12\x18\n\x10gemport_id_start\x18\n \x01(\x07\x12\x16\n\x0egemport_id_end\x18\x0b \x01(\x07\x12\x15\n\rflow_id_start\x18\r \x01(\x07\x12\x13\n\x0b\x66low_id_end\x18\x0e \x01(\x07\x12\x38\n\x06ranges\x18\x0f \x03(\x0b\x32(.openolt.DeviceInfo.DeviceResourceRanges\x1a\xde\x03\n\x14\x44\x65viceResourceRanges\x12\x10\n\x08intf_ids\x18\x01 \x03(\x07\x12\x12\n\ntechnology\x18\x02 \x01(\t\x12<\n\x05pools\x18\x03 \x03(\x0b\x32-.openolt.DeviceInfo.DeviceResourceRanges.Pool\x1a\xe1\x02\n\x04Pool\x12\x44\n\x04type\x18\x01 \x01(\x0e\x32\x36.openolt.DeviceInfo.DeviceResourceRanges.Pool.PoolType\x12J\n\x07sharing\x18\x02 \x01(\x0e\x32\x39.openolt.DeviceInfo.DeviceResourceRanges.Pool.SharingType\x12\r\n\x05start\x18\x03 \x01(\x07\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x07\"A\n\x08PoolType\x12\n\n\x06ONU_ID\x10\x00\x12\x0c\n\x08\x41LLOC_ID\x10\x01\x12\x0e\n\nGEMPORT_ID\x10\x02\x12\x0b\n\x07\x46LOW_ID\x10\x03\"h\n\x0bSharingType\x12\x16\n\x12\x44\x45\x44ICATED_PER_INTF\x10\x00\x12\x1f\n\x1bSHARED_BY_ALL_INTF_ALL_TECH\x10\x01\x12 \n\x1cSHARED_BY_ALL_INTF_SAME_TECH\x10\x02\"\x8c\x02\n\nClassifier\x12\x0e\n\x06o_tpid\x18\x01 \x01(\x07\x12\r\n\x05o_vid\x18\x02 \x01(\x07\x12\x0e\n\x06i_tpid\x18\x03 \x01(\x07\x12\r\n\x05i_vid\x18\x04 \x01(\x07\x12\x0f\n\x07o_pbits\x18\x05 \x01(\x07\x12\x0f\n\x07i_pbits\x18\x06 \x01(\x07\x12\x10\n\x08\x65th_type\x18\x07 \x01(\x07\x12\x0f\n\x07\x64st_mac\x18\x08 \x01(\x0c\x12\x0f\n\x07src_mac\x18\t \x01(\x0c\x12\x10\n\x08ip_proto\x18\n \x01(\x07\x12\x0e\n\x06\x64st_ip\x18\x0b \x01(\x07\x12\x0e\n\x06src_ip\x18\x0c \x01(\x07\x12\x10\n\x08src_port\x18\r \x01(\x07\x12\x10\n\x08\x64st_port\x18\x0e \x01(\x07\x12\x14\n\x0cpkt_tag_type\x18\x0f \x01(\t\"R\n\tActionCmd\x12\x15\n\radd_outer_tag\x18\x01 \x01(\x08\x12\x18\n\x10remove_outer_tag\x18\x02 \x01(\x08\x12\x14\n\x0ctrap_to_host\x18\x03 \x01(\x08\"\x89\x01\n\x06\x41\x63tion\x12\x1f\n\x03\x63md\x18\x01 \x01(\x0b\x32\x12.openolt.ActionCmd\x12\r\n\x05o_vid\x18\x02 \x01(\x07\x12\x0f\n\x07o_pbits\x18\x03 \x01(\x07\x12\x0e\n\x06o_tpid\x18\x04 \x01(\x07\x12\r\n\x05i_vid\x18\x05 \x01(\x07\x12\x0f\n\x07i_pbits\x18\x06 \x01(\x07\x12\x0e\n\x06i_tpid\x18\x07 \x01(\x07\"\x9e\x02\n\x04\x46low\x12\x16\n\x0e\x61\x63\x63\x65ss_intf_id\x18\x01 \x01(\x0f\x12\x0e\n\x06onu_id\x18\x02 \x01(\x0f\x12\x0e\n\x06uni_id\x18\x0b \x01(\x0f\x12\x0f\n\x07\x66low_id\x18\x03 \x01(\x07\x12\x11\n\tflow_type\x18\x04 \x01(\t\x12\x10\n\x08\x61lloc_id\x18\n \x01(\x0f\x12\x17\n\x0fnetwork_intf_id\x18\x05 \x01(\x0f\x12\x12\n\ngemport_id\x18\x06 \x01(\x0f\x12\'\n\nclassifier\x18\x07 \x01(\x0b\x32\x13.openolt.Classifier\x12\x1f\n\x06\x61\x63tion\x18\x08 \x01(\x0b\x32\x0f.openolt.Action\x12\x10\n\x08priority\x18\t \x01(\x0f\x12\x0e\n\x06\x63ookie\x18\x0c \x01(\x06\x12\x0f\n\x07port_no\x18\r \x01(\x07\":\n\x0cSerialNumber\x12\x11\n\tvendor_id\x18\x01 \x01(\x0c\x12\x17\n\x0fvendor_specific\x18\x02 \x01(\x0c\"\xfb\x02\n\x0ePortStatistics\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x10\n\x08rx_bytes\x18\x02 \x01(\x06\x12\x12\n\nrx_packets\x18\x03 \x01(\x06\x12\x18\n\x10rx_ucast_packets\x18\x04 \x01(\x06\x12\x18\n\x10rx_mcast_packets\x18\x05 \x01(\x06\x12\x18\n\x10rx_bcast_packets\x18\x06 \x01(\x06\x12\x18\n\x10rx_error_packets\x18\x07 \x01(\x06\x12\x10\n\x08tx_bytes\x18\x08 \x01(\x06\x12\x12\n\ntx_packets\x18\t \x01(\x06\x12\x18\n\x10tx_ucast_packets\x18\n \x01(\x06\x12\x18\n\x10tx_mcast_packets\x18\x0b \x01(\x06\x12\x18\n\x10tx_bcast_packets\x18\x0c \x01(\x06\x12\x18\n\x10tx_error_packets\x18\r \x01(\x06\x12\x15\n\rrx_crc_errors\x18\x0e \x01(\x06\x12\x12\n\nbip_errors\x18\x0f \x01(\x06\x12\x11\n\ttimestamp\x18\x10 \x01(\x07\"\x80\x01\n\x0e\x46lowStatistics\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\x07\x12\x10\n\x08rx_bytes\x18\x02 \x01(\x06\x12\x12\n\nrx_packets\x18\x03 \x01(\x06\x12\x10\n\x08tx_bytes\x18\x08 \x01(\x06\x12\x12\n\ntx_packets\x18\t \x01(\x06\x12\x11\n\ttimestamp\x18\x10 \x01(\x07\"0\n\rLosIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06status\x18\x02 \x01(\t\"F\n\x13\x44yingGaspIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x96\x01\n\x12OnuAlarmIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x12\n\nlos_status\x18\x03 \x01(\t\x12\x12\n\nlob_status\x18\x04 \x01(\t\x12\x18\n\x10lopc_miss_status\x18\x05 \x01(\t\x12\x1d\n\x15lopc_mic_error_status\x18\x06 \x01(\t\"N\n\x1bOnuStartupFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"m\n\x1aOnuSignalDegradeIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x1e\n\x16inverse_bit_error_rate\x18\x04 \x01(\x07\"m\n\x1aOnuDriftOfWindowIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05\x64rift\x18\x04 \x01(\x07\x12\x0f\n\x07new_eqd\x18\x05 \x01(\x07\"Q\n\x1eOnuLossOfOmciChannelIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"n\n\x1bOnuSignalsFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x1e\n\x16inverse_bit_error_rate\x18\x04 \x01(\x07\"d\n\"OnuTransmissionInterferenceWarning\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05\x64rift\x18\x04 \x01(\x07\"A\n\x1eOnuActivationFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\"?\n\x1cOnuProcessingErrorIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\"\xb3\x01\n\tScheduler\x12%\n\tdirection\x18\x01 \x01(\x0e\x32\x12.openolt.Direction\x12,\n\radditional_bw\x18\x02 \x01(\x0e\x32\x15.openolt.AdditionalBW\x12\x10\n\x08priority\x18\x03 \x01(\x07\x12\x0e\n\x06weight\x18\x04 \x01(\x07\x12/\n\x0csched_policy\x18\x05 \x01(\x0e\x32\x19.openolt.SchedulingPolicy\"\x90\x01\n\x12TrafficShapingInfo\x12\x0b\n\x03\x63ir\x18\x01 \x01(\x07\x12\x0b\n\x03\x63\x62s\x18\x02 \x01(\x07\x12\x0b\n\x03pir\x18\x03 \x01(\x07\x12\x0b\n\x03pbs\x18\x04 \x01(\x07\x12\x0b\n\x03gir\x18\x05 \x01(\x07\x12\x39\n\nadd_bw_ind\x18\x06 \x01(\x0e\x32%.openolt.InferredAdditionBWIndication\"\xa2\x01\n\x05Tcont\x12%\n\tdirection\x18\x01 \x01(\x0e\x32\x12.openolt.Direction\x12\x10\n\x08\x61lloc_id\x18\x02 \x01(\x07\x12%\n\tscheduler\x18\x03 \x01(\x0b\x32\x12.openolt.Scheduler\x12\x39\n\x14traffic_shaping_info\x18\x04 \x01(\x0b\x32\x1b.openolt.TrafficShapingInfo\"j\n\x06Tconts\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06uni_id\x18\x04 \x01(\x07\x12\x0f\n\x07port_no\x18\x05 \x01(\x07\x12\x1e\n\x06tconts\x18\x03 \x03(\x0b\x32\x0e.openolt.Tcont\"+\n\x15TailDropDiscardConfig\x12\x12\n\nqueue_size\x18\x01 \x01(\x07\"Y\n\x10RedDiscardConfig\x12\x15\n\rmin_threshold\x18\x01 \x01(\x07\x12\x15\n\rmax_threshold\x18\x02 \x01(\x07\x12\x17\n\x0fmax_probability\x18\x03 \x01(\x07\"\x90\x01\n\x11WRedDiscardConfig\x12(\n\x05green\x18\x01 \x01(\x0b\x32\x19.openolt.RedDiscardConfig\x12)\n\x06yellow\x18\x02 \x01(\x0b\x32\x19.openolt.RedDiscardConfig\x12&\n\x03red\x18\x03 \x01(\x0b\x32\x19.openolt.RedDiscardConfig\"\x89\x02\n\rDiscardConfig\x12.\n\x0e\x64iscard_policy\x18\x01 \x01(\x0e\x32\x16.openolt.DiscardPolicy\x12\x42\n\x18tail_drop_discard_config\x18\x02 \x01(\x0b\x32\x1e.openolt.TailDropDiscardConfigH\x00\x12\x37\n\x12red_discard_config\x18\x03 \x01(\x0b\x32\x19.openolt.RedDiscardConfigH\x00\x12\x39\n\x13wred_discard_config\x18\x04 \x01(\x0b\x32\x1a.openolt.WRedDiscardConfigH\x00\x42\x10\n\x0e\x64iscard_config\"\x07\n\x05\x45mpty*<\n\tDirection\x12\x0c\n\x08UPSTREAM\x10\x00\x12\x0e\n\nDOWNSTREAM\x10\x01\x12\x11\n\rBIDIRECTIONAL\x10\x02*;\n\x10SchedulingPolicy\x12\x07\n\x03WRR\x10\x00\x12\x12\n\x0eStrictPriority\x10\x01\x12\n\n\x06Hybrid\x10\x02*n\n\x0c\x41\x64\x64itionalBW\x12\x15\n\x11\x41\x64\x64itionalBW_None\x10\x00\x12\x13\n\x0f\x41\x64\x64itionalBW_NA\x10\x01\x12\x1b\n\x17\x41\x64\x64itionalBW_BestEffort\x10\x02\x12\x15\n\x11\x41\x64\x64itionalBW_Auto\x10\x03*?\n\rDiscardPolicy\x12\x0c\n\x08TailDrop\x10\x00\x12\r\n\tWTailDrop\x10\x01\x12\x07\n\x03Red\x10\x02\x12\x08\n\x04WRed\x10\x03*\x9c\x01\n\x1cInferredAdditionBWIndication\x12%\n!InferredAdditionBWIndication_None\x10\x00\x12(\n$InferredAdditionBWIndication_Assured\x10\x01\x12+\n\'InferredAdditionBWIndication_BestEffort\x10\x02\x32\xa7\x0b\n\x07Openolt\x12\x44\n\nDisableOlt\x12\x0e.openolt.Empty\x1a\x0e.openolt.Empty\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/Disable:\x01*\x12\x46\n\x0bReenableOlt\x12\x0e.openolt.Empty\x1a\x0e.openolt.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/Reenable:\x01*\x12\x45\n\x0b\x41\x63tivateOnu\x12\x0c.openolt.Onu\x1a\x0e.openolt.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/v1/EnableOnu:\x01*\x12H\n\rDeactivateOnu\x12\x0c.openolt.Onu\x1a\x0e.openolt.Empty\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/DisableOnu:\x01*\x12\x43\n\tDeleteOnu\x12\x0c.openolt.Onu\x1a\x0e.openolt.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/v1/DeleteOnu:\x01*\x12I\n\nOmciMsgOut\x12\x10.openolt.OmciMsg\x1a\x0e.openolt.Empty\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/OmciMsgOut:\x01*\x12O\n\x0cOnuPacketOut\x12\x12.openolt.OnuPacket\x1a\x0e.openolt.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/OnuPacketOut:\x01*\x12X\n\x0fUplinkPacketOut\x12\x15.openolt.UplinkPacket\x1a\x0e.openolt.Empty\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/UplinkPacketOut:\x01*\x12@\n\x07\x46lowAdd\x12\r.openolt.Flow\x1a\x0e.openolt.Empty\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/FlowAdd:\x01*\x12\x46\n\nFlowRemove\x12\r.openolt.Flow\x1a\x0e.openolt.Empty\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/FlowRemove:\x01*\x12S\n\x0eHeartbeatCheck\x12\x0e.openolt.Empty\x1a\x12.openolt.Heartbeat\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/HeartbeatCheck:\x01*\x12M\n\x0b\x45nablePonIf\x12\x12.openolt.Interface\x1a\x0e.openolt.Empty\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/EnablePonIf:\x01*\x12O\n\x0c\x44isablePonIf\x12\x12.openolt.Interface\x1a\x0e.openolt.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/DisablePonIf:\x01*\x12R\n\rGetDeviceInfo\x12\x0e.openolt.Empty\x1a\x13.openolt.DeviceInfo\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/GetDeviceInfo:\x01*\x12?\n\x06Reboot\x12\x0e.openolt.Empty\x1a\x0e.openolt.Empty\"\x15\x82\xd3\xe4\x93\x02\x0f\"\n/v1/Reboot:\x01*\x12U\n\x11\x43ollectStatistics\x12\x0e.openolt.Empty\x1a\x0e.openolt.Empty\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/CollectStatistics:\x01*\x12L\n\x0c\x43reateTconts\x12\x0f.openolt.Tconts\x1a\x0e.openolt.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/CreateTconts:\x01*\x12L\n\x0cRemoveTconts\x12\x0f.openolt.Tconts\x1a\x0e.openolt.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/RemoveTconts:\x01*\x12;\n\x10\x45nableIndication\x12\x0e.openolt.Empty\x1a\x13.openolt.Indication\"\x00\x30\x01\x62\x06proto3')
  ,
  dependencies=[annotations__pb2.DESCRIPTOR,])

_DIRECTION = _descriptor.EnumDescriptor(
  name='Direction',
  full_name='openolt.Direction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UPSTREAM', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOWNSTREAM', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BIDIRECTIONAL', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6664,
  serialized_end=6724,
)
_sym_db.RegisterEnumDescriptor(_DIRECTION)

Direction = enum_type_wrapper.EnumTypeWrapper(_DIRECTION)
_SCHEDULINGPOLICY = _descriptor.EnumDescriptor(
  name='SchedulingPolicy',
  full_name='openolt.SchedulingPolicy',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WRR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='StrictPriority', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Hybrid', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6726,
  serialized_end=6785,
)
_sym_db.RegisterEnumDescriptor(_SCHEDULINGPOLICY)

SchedulingPolicy = enum_type_wrapper.EnumTypeWrapper(_SCHEDULINGPOLICY)
_ADDITIONALBW = _descriptor.EnumDescriptor(
  name='AdditionalBW',
  full_name='openolt.AdditionalBW',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AdditionalBW_None', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AdditionalBW_NA', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AdditionalBW_BestEffort', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AdditionalBW_Auto', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6787,
  serialized_end=6897,
)
_sym_db.RegisterEnumDescriptor(_ADDITIONALBW)

AdditionalBW = enum_type_wrapper.EnumTypeWrapper(_ADDITIONALBW)
_DISCARDPOLICY = _descriptor.EnumDescriptor(
  name='DiscardPolicy',
  full_name='openolt.DiscardPolicy',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TailDrop', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WTailDrop', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Red', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WRed', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6899,
  serialized_end=6962,
)
_sym_db.RegisterEnumDescriptor(_DISCARDPOLICY)

DiscardPolicy = enum_type_wrapper.EnumTypeWrapper(_DISCARDPOLICY)
_INFERREDADDITIONBWINDICATION = _descriptor.EnumDescriptor(
  name='InferredAdditionBWIndication',
  full_name='openolt.InferredAdditionBWIndication',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='InferredAdditionBWIndication_None', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InferredAdditionBWIndication_Assured', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InferredAdditionBWIndication_BestEffort', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6965,
  serialized_end=7121,
)
_sym_db.RegisterEnumDescriptor(_INFERREDADDITIONBWINDICATION)

InferredAdditionBWIndication = enum_type_wrapper.EnumTypeWrapper(_INFERREDADDITIONBWINDICATION)
UPSTREAM = 0
DOWNSTREAM = 1
BIDIRECTIONAL = 2
WRR = 0
StrictPriority = 1
Hybrid = 2
AdditionalBW_None = 0
AdditionalBW_NA = 1
AdditionalBW_BestEffort = 2
AdditionalBW_Auto = 3
TailDrop = 0
WTailDrop = 1
Red = 2
WRed = 3
InferredAdditionBWIndication_None = 0
InferredAdditionBWIndication_Assured = 1
InferredAdditionBWIndication_BestEffort = 2


_DEVICEINFO_DEVICERESOURCERANGES_POOL_POOLTYPE = _descriptor.EnumDescriptor(
  name='PoolType',
  full_name='openolt.DeviceInfo.DeviceResourceRanges.Pool.PoolType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ONU_ID', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALLOC_ID', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GEMPORT_ID', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FLOW_ID', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2966,
  serialized_end=3031,
)
_sym_db.RegisterEnumDescriptor(_DEVICEINFO_DEVICERESOURCERANGES_POOL_POOLTYPE)

_DEVICEINFO_DEVICERESOURCERANGES_POOL_SHARINGTYPE = _descriptor.EnumDescriptor(
  name='SharingType',
  full_name='openolt.DeviceInfo.DeviceResourceRanges.Pool.SharingType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEDICATED_PER_INTF', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHARED_BY_ALL_INTF_ALL_TECH', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHARED_BY_ALL_INTF_SAME_TECH', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3033,
  serialized_end=3137,
)
_sym_db.RegisterEnumDescriptor(_DEVICEINFO_DEVICERESOURCERANGES_POOL_SHARINGTYPE)


_INDICATION = _descriptor.Descriptor(
  name='Indication',
  full_name='openolt.Indication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='olt_ind', full_name='openolt.Indication.olt_ind', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intf_ind', full_name='openolt.Indication.intf_ind', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intf_oper_ind', full_name='openolt.Indication.intf_oper_ind', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_disc_ind', full_name='openolt.Indication.onu_disc_ind', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_ind', full_name='openolt.Indication.onu_ind', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='omci_ind', full_name='openolt.Indication.omci_ind', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkt_ind', full_name='openolt.Indication.pkt_ind', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_stats', full_name='openolt.Indication.port_stats', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flow_stats', full_name='openolt.Indication.flow_stats', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alarm_ind', full_name='openolt.Indication.alarm_ind', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='openolt.Indication.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=46,
  serialized_end=535,
)


_ALARMINDICATION = _descriptor.Descriptor(
  name='AlarmIndication',
  full_name='openolt.AlarmIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='los_ind', full_name='openolt.AlarmIndication.los_ind', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dying_gasp_ind', full_name='openolt.AlarmIndication.dying_gasp_ind', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_alarm_ind', full_name='openolt.AlarmIndication.onu_alarm_ind', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_startup_fail_ind', full_name='openolt.AlarmIndication.onu_startup_fail_ind', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_signal_degrade_ind', full_name='openolt.AlarmIndication.onu_signal_degrade_ind', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_drift_of_window_ind', full_name='openolt.AlarmIndication.onu_drift_of_window_ind', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_loss_omci_ind', full_name='openolt.AlarmIndication.onu_loss_omci_ind', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_signals_fail_ind', full_name='openolt.AlarmIndication.onu_signals_fail_ind', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_tiwi_ind', full_name='openolt.AlarmIndication.onu_tiwi_ind', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_activation_fail_ind', full_name='openolt.AlarmIndication.onu_activation_fail_ind', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_processing_error_ind', full_name='openolt.AlarmIndication.onu_processing_error_ind', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='openolt.AlarmIndication.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=538,
  serialized_end=1289,
)


_OLTINDICATION = _descriptor.Descriptor(
  name='OltIndication',
  full_name='openolt.OltIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='oper_state', full_name='openolt.OltIndication.oper_state', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1291,
  serialized_end=1326,
)


_INTFINDICATION = _descriptor.Descriptor(
  name='IntfIndication',
  full_name='openolt.IntfIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.IntfIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oper_state', full_name='openolt.IntfIndication.oper_state', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1328,
  serialized_end=1381,
)


_ONUDISCINDICATION = _descriptor.Descriptor(
  name='OnuDiscIndication',
  full_name='openolt.OnuDiscIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuDiscIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='openolt.OnuDiscIndication.serial_number', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1383,
  serialized_end=1465,
)


_ONUINDICATION = _descriptor.Descriptor(
  name='OnuIndication',
  full_name='openolt.OnuIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oper_state', full_name='openolt.OnuIndication.oper_state', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='admin_state', full_name='openolt.OnuIndication.admin_state', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='openolt.OnuIndication.serial_number', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1468,
  serialized_end=1603,
)


_INTFOPERINDICATION = _descriptor.Descriptor(
  name='IntfOperIndication',
  full_name='openolt.IntfOperIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='openolt.IntfOperIndication.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.IntfOperIndication.intf_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oper_state', full_name='openolt.IntfOperIndication.oper_state', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1605,
  serialized_end=1676,
)


_OMCIINDICATION = _descriptor.Descriptor(
  name='OmciIndication',
  full_name='openolt.OmciIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OmciIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OmciIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkt', full_name='openolt.OmciIndication.pkt', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1678,
  serialized_end=1740,
)


_PACKETINDICATION = _descriptor.Descriptor(
  name='PacketIndication',
  full_name='openolt.PacketIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_type', full_name='openolt.PacketIndication.intf_type', index=0,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.PacketIndication.intf_id', index=1,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gemport_id', full_name='openolt.PacketIndication.gemport_id', index=2,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flow_id', full_name='openolt.PacketIndication.flow_id', index=3,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='openolt.PacketIndication.port_no', index=4,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cookie', full_name='openolt.PacketIndication.cookie', index=5,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkt', full_name='openolt.PacketIndication.pkt', index=6,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1743,
  serialized_end=1880,
)


_INTERFACE = _descriptor.Descriptor(
  name='Interface',
  full_name='openolt.Interface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.Interface.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1882,
  serialized_end=1910,
)


_HEARTBEAT = _descriptor.Descriptor(
  name='Heartbeat',
  full_name='openolt.Heartbeat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='heartbeat_signature', full_name='openolt.Heartbeat.heartbeat_signature', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1912,
  serialized_end=1952,
)


_ONU = _descriptor.Descriptor(
  name='Onu',
  full_name='openolt.Onu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.Onu.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.Onu.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='openolt.Onu.serial_number', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pir', full_name='openolt.Onu.pir', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1954,
  serialized_end=2051,
)


_OMCIMSG = _descriptor.Descriptor(
  name='OmciMsg',
  full_name='openolt.OmciMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OmciMsg.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OmciMsg.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkt', full_name='openolt.OmciMsg.pkt', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2053,
  serialized_end=2108,
)


_ONUPACKET = _descriptor.Descriptor(
  name='OnuPacket',
  full_name='openolt.OnuPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuPacket.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuPacket.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='openolt.OnuPacket.port_no', index=2,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkt', full_name='openolt.OnuPacket.pkt', index=3,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2110,
  serialized_end=2184,
)


_UPLINKPACKET = _descriptor.Descriptor(
  name='UplinkPacket',
  full_name='openolt.UplinkPacket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.UplinkPacket.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkt', full_name='openolt.UplinkPacket.pkt', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2186,
  serialized_end=2230,
)


_DEVICEINFO_DEVICERESOURCERANGES_POOL = _descriptor.Descriptor(
  name='Pool',
  full_name='openolt.DeviceInfo.DeviceResourceRanges.Pool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='openolt.DeviceInfo.DeviceResourceRanges.Pool.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sharing', full_name='openolt.DeviceInfo.DeviceResourceRanges.Pool.sharing', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='openolt.DeviceInfo.DeviceResourceRanges.Pool.start', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='openolt.DeviceInfo.DeviceResourceRanges.Pool.end', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEVICEINFO_DEVICERESOURCERANGES_POOL_POOLTYPE,
    _DEVICEINFO_DEVICERESOURCERANGES_POOL_SHARINGTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2784,
  serialized_end=3137,
)

_DEVICEINFO_DEVICERESOURCERANGES = _descriptor.Descriptor(
  name='DeviceResourceRanges',
  full_name='openolt.DeviceInfo.DeviceResourceRanges',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_ids', full_name='openolt.DeviceInfo.DeviceResourceRanges.intf_ids', index=0,
      number=1, type=7, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='technology', full_name='openolt.DeviceInfo.DeviceResourceRanges.technology', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pools', full_name='openolt.DeviceInfo.DeviceResourceRanges.pools', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DEVICEINFO_DEVICERESOURCERANGES_POOL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2659,
  serialized_end=3137,
)

_DEVICEINFO = _descriptor.Descriptor(
  name='DeviceInfo',
  full_name='openolt.DeviceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor', full_name='openolt.DeviceInfo.vendor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='model', full_name='openolt.DeviceInfo.model', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hardware_version', full_name='openolt.DeviceInfo.hardware_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='firmware_version', full_name='openolt.DeviceInfo.firmware_version', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='openolt.DeviceInfo.device_id', index=4,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_serial_number', full_name='openolt.DeviceInfo.device_serial_number', index=5,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pon_ports', full_name='openolt.DeviceInfo.pon_ports', index=6,
      number=12, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='technology', full_name='openolt.DeviceInfo.technology', index=7,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id_start', full_name='openolt.DeviceInfo.onu_id_start', index=8,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id_end', full_name='openolt.DeviceInfo.onu_id_end', index=9,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alloc_id_start', full_name='openolt.DeviceInfo.alloc_id_start', index=10,
      number=8, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alloc_id_end', full_name='openolt.DeviceInfo.alloc_id_end', index=11,
      number=9, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gemport_id_start', full_name='openolt.DeviceInfo.gemport_id_start', index=12,
      number=10, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gemport_id_end', full_name='openolt.DeviceInfo.gemport_id_end', index=13,
      number=11, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flow_id_start', full_name='openolt.DeviceInfo.flow_id_start', index=14,
      number=13, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flow_id_end', full_name='openolt.DeviceInfo.flow_id_end', index=15,
      number=14, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ranges', full_name='openolt.DeviceInfo.ranges', index=16,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DEVICEINFO_DEVICERESOURCERANGES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2233,
  serialized_end=3137,
)


_CLASSIFIER = _descriptor.Descriptor(
  name='Classifier',
  full_name='openolt.Classifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='o_tpid', full_name='openolt.Classifier.o_tpid', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='o_vid', full_name='openolt.Classifier.o_vid', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='i_tpid', full_name='openolt.Classifier.i_tpid', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='i_vid', full_name='openolt.Classifier.i_vid', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='o_pbits', full_name='openolt.Classifier.o_pbits', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='i_pbits', full_name='openolt.Classifier.i_pbits', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eth_type', full_name='openolt.Classifier.eth_type', index=6,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_mac', full_name='openolt.Classifier.dst_mac', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='src_mac', full_name='openolt.Classifier.src_mac', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip_proto', full_name='openolt.Classifier.ip_proto', index=9,
      number=10, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_ip', full_name='openolt.Classifier.dst_ip', index=10,
      number=11, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='src_ip', full_name='openolt.Classifier.src_ip', index=11,
      number=12, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='src_port', full_name='openolt.Classifier.src_port', index=12,
      number=13, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_port', full_name='openolt.Classifier.dst_port', index=13,
      number=14, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pkt_tag_type', full_name='openolt.Classifier.pkt_tag_type', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3140,
  serialized_end=3408,
)


_ACTIONCMD = _descriptor.Descriptor(
  name='ActionCmd',
  full_name='openolt.ActionCmd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='add_outer_tag', full_name='openolt.ActionCmd.add_outer_tag', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove_outer_tag', full_name='openolt.ActionCmd.remove_outer_tag', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trap_to_host', full_name='openolt.ActionCmd.trap_to_host', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3410,
  serialized_end=3492,
)


_ACTION = _descriptor.Descriptor(
  name='Action',
  full_name='openolt.Action',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd', full_name='openolt.Action.cmd', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='o_vid', full_name='openolt.Action.o_vid', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='o_pbits', full_name='openolt.Action.o_pbits', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='o_tpid', full_name='openolt.Action.o_tpid', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='i_vid', full_name='openolt.Action.i_vid', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='i_pbits', full_name='openolt.Action.i_pbits', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='i_tpid', full_name='openolt.Action.i_tpid', index=6,
      number=7, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3495,
  serialized_end=3632,
)


_FLOW = _descriptor.Descriptor(
  name='Flow',
  full_name='openolt.Flow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_intf_id', full_name='openolt.Flow.access_intf_id', index=0,
      number=1, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.Flow.onu_id', index=1,
      number=2, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uni_id', full_name='openolt.Flow.uni_id', index=2,
      number=11, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flow_id', full_name='openolt.Flow.flow_id', index=3,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flow_type', full_name='openolt.Flow.flow_type', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alloc_id', full_name='openolt.Flow.alloc_id', index=5,
      number=10, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='network_intf_id', full_name='openolt.Flow.network_intf_id', index=6,
      number=5, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gemport_id', full_name='openolt.Flow.gemport_id', index=7,
      number=6, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='classifier', full_name='openolt.Flow.classifier', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='openolt.Flow.action', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='priority', full_name='openolt.Flow.priority', index=10,
      number=9, type=15, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cookie', full_name='openolt.Flow.cookie', index=11,
      number=12, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='openolt.Flow.port_no', index=12,
      number=13, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3635,
  serialized_end=3921,
)


_SERIALNUMBER = _descriptor.Descriptor(
  name='SerialNumber',
  full_name='openolt.SerialNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vendor_id', full_name='openolt.SerialNumber.vendor_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vendor_specific', full_name='openolt.SerialNumber.vendor_specific', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3923,
  serialized_end=3981,
)


_PORTSTATISTICS = _descriptor.Descriptor(
  name='PortStatistics',
  full_name='openolt.PortStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.PortStatistics.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rx_bytes', full_name='openolt.PortStatistics.rx_bytes', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rx_packets', full_name='openolt.PortStatistics.rx_packets', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rx_ucast_packets', full_name='openolt.PortStatistics.rx_ucast_packets', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rx_mcast_packets', full_name='openolt.PortStatistics.rx_mcast_packets', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rx_bcast_packets', full_name='openolt.PortStatistics.rx_bcast_packets', index=5,
      number=6, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rx_error_packets', full_name='openolt.PortStatistics.rx_error_packets', index=6,
      number=7, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_bytes', full_name='openolt.PortStatistics.tx_bytes', index=7,
      number=8, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_packets', full_name='openolt.PortStatistics.tx_packets', index=8,
      number=9, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_ucast_packets', full_name='openolt.PortStatistics.tx_ucast_packets', index=9,
      number=10, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_mcast_packets', full_name='openolt.PortStatistics.tx_mcast_packets', index=10,
      number=11, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_bcast_packets', full_name='openolt.PortStatistics.tx_bcast_packets', index=11,
      number=12, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_error_packets', full_name='openolt.PortStatistics.tx_error_packets', index=12,
      number=13, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rx_crc_errors', full_name='openolt.PortStatistics.rx_crc_errors', index=13,
      number=14, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bip_errors', full_name='openolt.PortStatistics.bip_errors', index=14,
      number=15, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='openolt.PortStatistics.timestamp', index=15,
      number=16, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3984,
  serialized_end=4363,
)


_FLOWSTATISTICS = _descriptor.Descriptor(
  name='FlowStatistics',
  full_name='openolt.FlowStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flow_id', full_name='openolt.FlowStatistics.flow_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rx_bytes', full_name='openolt.FlowStatistics.rx_bytes', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rx_packets', full_name='openolt.FlowStatistics.rx_packets', index=2,
      number=3, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_bytes', full_name='openolt.FlowStatistics.tx_bytes', index=3,
      number=8, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_packets', full_name='openolt.FlowStatistics.tx_packets', index=4,
      number=9, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='openolt.FlowStatistics.timestamp', index=5,
      number=16, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4366,
  serialized_end=4494,
)


_LOSINDICATION = _descriptor.Descriptor(
  name='LosIndication',
  full_name='openolt.LosIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.LosIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.LosIndication.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4496,
  serialized_end=4544,
)


_DYINGGASPINDICATION = _descriptor.Descriptor(
  name='DyingGaspIndication',
  full_name='openolt.DyingGaspIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.DyingGaspIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.DyingGaspIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.DyingGaspIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4546,
  serialized_end=4616,
)


_ONUALARMINDICATION = _descriptor.Descriptor(
  name='OnuAlarmIndication',
  full_name='openolt.OnuAlarmIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuAlarmIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuAlarmIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='los_status', full_name='openolt.OnuAlarmIndication.los_status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lob_status', full_name='openolt.OnuAlarmIndication.lob_status', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lopc_miss_status', full_name='openolt.OnuAlarmIndication.lopc_miss_status', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lopc_mic_error_status', full_name='openolt.OnuAlarmIndication.lopc_mic_error_status', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4619,
  serialized_end=4769,
)


_ONUSTARTUPFAILUREINDICATION = _descriptor.Descriptor(
  name='OnuStartupFailureIndication',
  full_name='openolt.OnuStartupFailureIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuStartupFailureIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuStartupFailureIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuStartupFailureIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4771,
  serialized_end=4849,
)


_ONUSIGNALDEGRADEINDICATION = _descriptor.Descriptor(
  name='OnuSignalDegradeIndication',
  full_name='openolt.OnuSignalDegradeIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuSignalDegradeIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuSignalDegradeIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuSignalDegradeIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_bit_error_rate', full_name='openolt.OnuSignalDegradeIndication.inverse_bit_error_rate', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4851,
  serialized_end=4960,
)


_ONUDRIFTOFWINDOWINDICATION = _descriptor.Descriptor(
  name='OnuDriftOfWindowIndication',
  full_name='openolt.OnuDriftOfWindowIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuDriftOfWindowIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuDriftOfWindowIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuDriftOfWindowIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drift', full_name='openolt.OnuDriftOfWindowIndication.drift', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_eqd', full_name='openolt.OnuDriftOfWindowIndication.new_eqd', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4962,
  serialized_end=5071,
)


_ONULOSSOFOMCICHANNELINDICATION = _descriptor.Descriptor(
  name='OnuLossOfOmciChannelIndication',
  full_name='openolt.OnuLossOfOmciChannelIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuLossOfOmciChannelIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuLossOfOmciChannelIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuLossOfOmciChannelIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5073,
  serialized_end=5154,
)


_ONUSIGNALSFAILUREINDICATION = _descriptor.Descriptor(
  name='OnuSignalsFailureIndication',
  full_name='openolt.OnuSignalsFailureIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuSignalsFailureIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuSignalsFailureIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuSignalsFailureIndication.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_bit_error_rate', full_name='openolt.OnuSignalsFailureIndication.inverse_bit_error_rate', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5156,
  serialized_end=5266,
)


_ONUTRANSMISSIONINTERFERENCEWARNING = _descriptor.Descriptor(
  name='OnuTransmissionInterferenceWarning',
  full_name='openolt.OnuTransmissionInterferenceWarning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuTransmissionInterferenceWarning.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuTransmissionInterferenceWarning.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='openolt.OnuTransmissionInterferenceWarning.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drift', full_name='openolt.OnuTransmissionInterferenceWarning.drift', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5268,
  serialized_end=5368,
)


_ONUACTIVATIONFAILUREINDICATION = _descriptor.Descriptor(
  name='OnuActivationFailureIndication',
  full_name='openolt.OnuActivationFailureIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuActivationFailureIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuActivationFailureIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5370,
  serialized_end=5435,
)


_ONUPROCESSINGERRORINDICATION = _descriptor.Descriptor(
  name='OnuProcessingErrorIndication',
  full_name='openolt.OnuProcessingErrorIndication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.OnuProcessingErrorIndication.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.OnuProcessingErrorIndication.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5437,
  serialized_end=5500,
)


_SCHEDULER = _descriptor.Descriptor(
  name='Scheduler',
  full_name='openolt.Scheduler',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='direction', full_name='openolt.Scheduler.direction', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='additional_bw', full_name='openolt.Scheduler.additional_bw', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='priority', full_name='openolt.Scheduler.priority', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='weight', full_name='openolt.Scheduler.weight', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sched_policy', full_name='openolt.Scheduler.sched_policy', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5503,
  serialized_end=5682,
)


_TRAFFICSHAPINGINFO = _descriptor.Descriptor(
  name='TrafficShapingInfo',
  full_name='openolt.TrafficShapingInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cir', full_name='openolt.TrafficShapingInfo.cir', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cbs', full_name='openolt.TrafficShapingInfo.cbs', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pir', full_name='openolt.TrafficShapingInfo.pir', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pbs', full_name='openolt.TrafficShapingInfo.pbs', index=3,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gir', full_name='openolt.TrafficShapingInfo.gir', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='add_bw_ind', full_name='openolt.TrafficShapingInfo.add_bw_ind', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5685,
  serialized_end=5829,
)


_TCONT = _descriptor.Descriptor(
  name='Tcont',
  full_name='openolt.Tcont',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='direction', full_name='openolt.Tcont.direction', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='alloc_id', full_name='openolt.Tcont.alloc_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduler', full_name='openolt.Tcont.scheduler', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='traffic_shaping_info', full_name='openolt.Tcont.traffic_shaping_info', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5832,
  serialized_end=5994,
)


_TCONTS = _descriptor.Descriptor(
  name='Tconts',
  full_name='openolt.Tconts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intf_id', full_name='openolt.Tconts.intf_id', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='onu_id', full_name='openolt.Tconts.onu_id', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uni_id', full_name='openolt.Tconts.uni_id', index=2,
      number=4, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port_no', full_name='openolt.Tconts.port_no', index=3,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tconts', full_name='openolt.Tconts.tconts', index=4,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5996,
  serialized_end=6102,
)


_TAILDROPDISCARDCONFIG = _descriptor.Descriptor(
  name='TailDropDiscardConfig',
  full_name='openolt.TailDropDiscardConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='queue_size', full_name='openolt.TailDropDiscardConfig.queue_size', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6104,
  serialized_end=6147,
)


_REDDISCARDCONFIG = _descriptor.Descriptor(
  name='RedDiscardConfig',
  full_name='openolt.RedDiscardConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_threshold', full_name='openolt.RedDiscardConfig.min_threshold', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_threshold', full_name='openolt.RedDiscardConfig.max_threshold', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_probability', full_name='openolt.RedDiscardConfig.max_probability', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6149,
  serialized_end=6238,
)


_WREDDISCARDCONFIG = _descriptor.Descriptor(
  name='WRedDiscardConfig',
  full_name='openolt.WRedDiscardConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='green', full_name='openolt.WRedDiscardConfig.green', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yellow', full_name='openolt.WRedDiscardConfig.yellow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='red', full_name='openolt.WRedDiscardConfig.red', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6241,
  serialized_end=6385,
)


_DISCARDCONFIG = _descriptor.Descriptor(
  name='DiscardConfig',
  full_name='openolt.DiscardConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='discard_policy', full_name='openolt.DiscardConfig.discard_policy', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tail_drop_discard_config', full_name='openolt.DiscardConfig.tail_drop_discard_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='red_discard_config', full_name='openolt.DiscardConfig.red_discard_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wred_discard_config', full_name='openolt.DiscardConfig.wred_discard_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='discard_config', full_name='openolt.DiscardConfig.discard_config',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=6388,
  serialized_end=6653,
)


_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='openolt.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6655,
  serialized_end=6662,
)

_INDICATION.fields_by_name['olt_ind'].message_type = _OLTINDICATION
_INDICATION.fields_by_name['intf_ind'].message_type = _INTFINDICATION
_INDICATION.fields_by_name['intf_oper_ind'].message_type = _INTFOPERINDICATION
_INDICATION.fields_by_name['onu_disc_ind'].message_type = _ONUDISCINDICATION
_INDICATION.fields_by_name['onu_ind'].message_type = _ONUINDICATION
_INDICATION.fields_by_name['omci_ind'].message_type = _OMCIINDICATION
_INDICATION.fields_by_name['pkt_ind'].message_type = _PACKETINDICATION
_INDICATION.fields_by_name['port_stats'].message_type = _PORTSTATISTICS
_INDICATION.fields_by_name['flow_stats'].message_type = _FLOWSTATISTICS
_INDICATION.fields_by_name['alarm_ind'].message_type = _ALARMINDICATION
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['olt_ind'])
_INDICATION.fields_by_name['olt_ind'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['intf_ind'])
_INDICATION.fields_by_name['intf_ind'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['intf_oper_ind'])
_INDICATION.fields_by_name['intf_oper_ind'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['onu_disc_ind'])
_INDICATION.fields_by_name['onu_disc_ind'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['onu_ind'])
_INDICATION.fields_by_name['onu_ind'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['omci_ind'])
_INDICATION.fields_by_name['omci_ind'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['pkt_ind'])
_INDICATION.fields_by_name['pkt_ind'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['port_stats'])
_INDICATION.fields_by_name['port_stats'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['flow_stats'])
_INDICATION.fields_by_name['flow_stats'].containing_oneof = _INDICATION.oneofs_by_name['data']
_INDICATION.oneofs_by_name['data'].fields.append(
  _INDICATION.fields_by_name['alarm_ind'])
_INDICATION.fields_by_name['alarm_ind'].containing_oneof = _INDICATION.oneofs_by_name['data']
_ALARMINDICATION.fields_by_name['los_ind'].message_type = _LOSINDICATION
_ALARMINDICATION.fields_by_name['dying_gasp_ind'].message_type = _DYINGGASPINDICATION
_ALARMINDICATION.fields_by_name['onu_alarm_ind'].message_type = _ONUALARMINDICATION
_ALARMINDICATION.fields_by_name['onu_startup_fail_ind'].message_type = _ONUSTARTUPFAILUREINDICATION
_ALARMINDICATION.fields_by_name['onu_signal_degrade_ind'].message_type = _ONUSIGNALDEGRADEINDICATION
_ALARMINDICATION.fields_by_name['onu_drift_of_window_ind'].message_type = _ONUDRIFTOFWINDOWINDICATION
_ALARMINDICATION.fields_by_name['onu_loss_omci_ind'].message_type = _ONULOSSOFOMCICHANNELINDICATION
_ALARMINDICATION.fields_by_name['onu_signals_fail_ind'].message_type = _ONUSIGNALSFAILUREINDICATION
_ALARMINDICATION.fields_by_name['onu_tiwi_ind'].message_type = _ONUTRANSMISSIONINTERFERENCEWARNING
_ALARMINDICATION.fields_by_name['onu_activation_fail_ind'].message_type = _ONUACTIVATIONFAILUREINDICATION
_ALARMINDICATION.fields_by_name['onu_processing_error_ind'].message_type = _ONUPROCESSINGERRORINDICATION
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['los_ind'])
_ALARMINDICATION.fields_by_name['los_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['dying_gasp_ind'])
_ALARMINDICATION.fields_by_name['dying_gasp_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_alarm_ind'])
_ALARMINDICATION.fields_by_name['onu_alarm_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_startup_fail_ind'])
_ALARMINDICATION.fields_by_name['onu_startup_fail_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_signal_degrade_ind'])
_ALARMINDICATION.fields_by_name['onu_signal_degrade_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_drift_of_window_ind'])
_ALARMINDICATION.fields_by_name['onu_drift_of_window_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_loss_omci_ind'])
_ALARMINDICATION.fields_by_name['onu_loss_omci_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_signals_fail_ind'])
_ALARMINDICATION.fields_by_name['onu_signals_fail_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_tiwi_ind'])
_ALARMINDICATION.fields_by_name['onu_tiwi_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_activation_fail_ind'])
_ALARMINDICATION.fields_by_name['onu_activation_fail_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ALARMINDICATION.oneofs_by_name['data'].fields.append(
  _ALARMINDICATION.fields_by_name['onu_processing_error_ind'])
_ALARMINDICATION.fields_by_name['onu_processing_error_ind'].containing_oneof = _ALARMINDICATION.oneofs_by_name['data']
_ONUDISCINDICATION.fields_by_name['serial_number'].message_type = _SERIALNUMBER
_ONUINDICATION.fields_by_name['serial_number'].message_type = _SERIALNUMBER
_ONU.fields_by_name['serial_number'].message_type = _SERIALNUMBER
_DEVICEINFO_DEVICERESOURCERANGES_POOL.fields_by_name['type'].enum_type = _DEVICEINFO_DEVICERESOURCERANGES_POOL_POOLTYPE
_DEVICEINFO_DEVICERESOURCERANGES_POOL.fields_by_name['sharing'].enum_type = _DEVICEINFO_DEVICERESOURCERANGES_POOL_SHARINGTYPE
_DEVICEINFO_DEVICERESOURCERANGES_POOL.containing_type = _DEVICEINFO_DEVICERESOURCERANGES
_DEVICEINFO_DEVICERESOURCERANGES_POOL_POOLTYPE.containing_type = _DEVICEINFO_DEVICERESOURCERANGES_POOL
_DEVICEINFO_DEVICERESOURCERANGES_POOL_SHARINGTYPE.containing_type = _DEVICEINFO_DEVICERESOURCERANGES_POOL
_DEVICEINFO_DEVICERESOURCERANGES.fields_by_name['pools'].message_type = _DEVICEINFO_DEVICERESOURCERANGES_POOL
_DEVICEINFO_DEVICERESOURCERANGES.containing_type = _DEVICEINFO
_DEVICEINFO.fields_by_name['ranges'].message_type = _DEVICEINFO_DEVICERESOURCERANGES
_ACTION.fields_by_name['cmd'].message_type = _ACTIONCMD
_FLOW.fields_by_name['classifier'].message_type = _CLASSIFIER
_FLOW.fields_by_name['action'].message_type = _ACTION
_SCHEDULER.fields_by_name['direction'].enum_type = _DIRECTION
_SCHEDULER.fields_by_name['additional_bw'].enum_type = _ADDITIONALBW
_SCHEDULER.fields_by_name['sched_policy'].enum_type = _SCHEDULINGPOLICY
_TRAFFICSHAPINGINFO.fields_by_name['add_bw_ind'].enum_type = _INFERREDADDITIONBWINDICATION
_TCONT.fields_by_name['direction'].enum_type = _DIRECTION
_TCONT.fields_by_name['scheduler'].message_type = _SCHEDULER
_TCONT.fields_by_name['traffic_shaping_info'].message_type = _TRAFFICSHAPINGINFO
_TCONTS.fields_by_name['tconts'].message_type = _TCONT
_WREDDISCARDCONFIG.fields_by_name['green'].message_type = _REDDISCARDCONFIG
_WREDDISCARDCONFIG.fields_by_name['yellow'].message_type = _REDDISCARDCONFIG
_WREDDISCARDCONFIG.fields_by_name['red'].message_type = _REDDISCARDCONFIG
_DISCARDCONFIG.fields_by_name['discard_policy'].enum_type = _DISCARDPOLICY
_DISCARDCONFIG.fields_by_name['tail_drop_discard_config'].message_type = _TAILDROPDISCARDCONFIG
_DISCARDCONFIG.fields_by_name['red_discard_config'].message_type = _REDDISCARDCONFIG
_DISCARDCONFIG.fields_by_name['wred_discard_config'].message_type = _WREDDISCARDCONFIG
_DISCARDCONFIG.oneofs_by_name['discard_config'].fields.append(
  _DISCARDCONFIG.fields_by_name['tail_drop_discard_config'])
_DISCARDCONFIG.fields_by_name['tail_drop_discard_config'].containing_oneof = _DISCARDCONFIG.oneofs_by_name['discard_config']
_DISCARDCONFIG.oneofs_by_name['discard_config'].fields.append(
  _DISCARDCONFIG.fields_by_name['red_discard_config'])
_DISCARDCONFIG.fields_by_name['red_discard_config'].containing_oneof = _DISCARDCONFIG.oneofs_by_name['discard_config']
_DISCARDCONFIG.oneofs_by_name['discard_config'].fields.append(
  _DISCARDCONFIG.fields_by_name['wred_discard_config'])
_DISCARDCONFIG.fields_by_name['wred_discard_config'].containing_oneof = _DISCARDCONFIG.oneofs_by_name['discard_config']
DESCRIPTOR.message_types_by_name['Indication'] = _INDICATION
DESCRIPTOR.message_types_by_name['AlarmIndication'] = _ALARMINDICATION
DESCRIPTOR.message_types_by_name['OltIndication'] = _OLTINDICATION
DESCRIPTOR.message_types_by_name['IntfIndication'] = _INTFINDICATION
DESCRIPTOR.message_types_by_name['OnuDiscIndication'] = _ONUDISCINDICATION
DESCRIPTOR.message_types_by_name['OnuIndication'] = _ONUINDICATION
DESCRIPTOR.message_types_by_name['IntfOperIndication'] = _INTFOPERINDICATION
DESCRIPTOR.message_types_by_name['OmciIndication'] = _OMCIINDICATION
DESCRIPTOR.message_types_by_name['PacketIndication'] = _PACKETINDICATION
DESCRIPTOR.message_types_by_name['Interface'] = _INTERFACE
DESCRIPTOR.message_types_by_name['Heartbeat'] = _HEARTBEAT
DESCRIPTOR.message_types_by_name['Onu'] = _ONU
DESCRIPTOR.message_types_by_name['OmciMsg'] = _OMCIMSG
DESCRIPTOR.message_types_by_name['OnuPacket'] = _ONUPACKET
DESCRIPTOR.message_types_by_name['UplinkPacket'] = _UPLINKPACKET
DESCRIPTOR.message_types_by_name['DeviceInfo'] = _DEVICEINFO
DESCRIPTOR.message_types_by_name['Classifier'] = _CLASSIFIER
DESCRIPTOR.message_types_by_name['ActionCmd'] = _ACTIONCMD
DESCRIPTOR.message_types_by_name['Action'] = _ACTION
DESCRIPTOR.message_types_by_name['Flow'] = _FLOW
DESCRIPTOR.message_types_by_name['SerialNumber'] = _SERIALNUMBER
DESCRIPTOR.message_types_by_name['PortStatistics'] = _PORTSTATISTICS
DESCRIPTOR.message_types_by_name['FlowStatistics'] = _FLOWSTATISTICS
DESCRIPTOR.message_types_by_name['LosIndication'] = _LOSINDICATION
DESCRIPTOR.message_types_by_name['DyingGaspIndication'] = _DYINGGASPINDICATION
DESCRIPTOR.message_types_by_name['OnuAlarmIndication'] = _ONUALARMINDICATION
DESCRIPTOR.message_types_by_name['OnuStartupFailureIndication'] = _ONUSTARTUPFAILUREINDICATION
DESCRIPTOR.message_types_by_name['OnuSignalDegradeIndication'] = _ONUSIGNALDEGRADEINDICATION
DESCRIPTOR.message_types_by_name['OnuDriftOfWindowIndication'] = _ONUDRIFTOFWINDOWINDICATION
DESCRIPTOR.message_types_by_name['OnuLossOfOmciChannelIndication'] = _ONULOSSOFOMCICHANNELINDICATION
DESCRIPTOR.message_types_by_name['OnuSignalsFailureIndication'] = _ONUSIGNALSFAILUREINDICATION
DESCRIPTOR.message_types_by_name['OnuTransmissionInterferenceWarning'] = _ONUTRANSMISSIONINTERFERENCEWARNING
DESCRIPTOR.message_types_by_name['OnuActivationFailureIndication'] = _ONUACTIVATIONFAILUREINDICATION
DESCRIPTOR.message_types_by_name['OnuProcessingErrorIndication'] = _ONUPROCESSINGERRORINDICATION
DESCRIPTOR.message_types_by_name['Scheduler'] = _SCHEDULER
DESCRIPTOR.message_types_by_name['TrafficShapingInfo'] = _TRAFFICSHAPINGINFO
DESCRIPTOR.message_types_by_name['Tcont'] = _TCONT
DESCRIPTOR.message_types_by_name['Tconts'] = _TCONTS
DESCRIPTOR.message_types_by_name['TailDropDiscardConfig'] = _TAILDROPDISCARDCONFIG
DESCRIPTOR.message_types_by_name['RedDiscardConfig'] = _REDDISCARDCONFIG
DESCRIPTOR.message_types_by_name['WRedDiscardConfig'] = _WREDDISCARDCONFIG
DESCRIPTOR.message_types_by_name['DiscardConfig'] = _DISCARDCONFIG
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.enum_types_by_name['Direction'] = _DIRECTION
DESCRIPTOR.enum_types_by_name['SchedulingPolicy'] = _SCHEDULINGPOLICY
DESCRIPTOR.enum_types_by_name['AdditionalBW'] = _ADDITIONALBW
DESCRIPTOR.enum_types_by_name['DiscardPolicy'] = _DISCARDPOLICY
DESCRIPTOR.enum_types_by_name['InferredAdditionBWIndication'] = _INFERREDADDITIONBWINDICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Indication = _reflection.GeneratedProtocolMessageType('Indication', (_message.Message,), dict(
  DESCRIPTOR = _INDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Indication)
  ))
_sym_db.RegisterMessage(Indication)

AlarmIndication = _reflection.GeneratedProtocolMessageType('AlarmIndication', (_message.Message,), dict(
  DESCRIPTOR = _ALARMINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.AlarmIndication)
  ))
_sym_db.RegisterMessage(AlarmIndication)

OltIndication = _reflection.GeneratedProtocolMessageType('OltIndication', (_message.Message,), dict(
  DESCRIPTOR = _OLTINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OltIndication)
  ))
_sym_db.RegisterMessage(OltIndication)

IntfIndication = _reflection.GeneratedProtocolMessageType('IntfIndication', (_message.Message,), dict(
  DESCRIPTOR = _INTFINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.IntfIndication)
  ))
_sym_db.RegisterMessage(IntfIndication)

OnuDiscIndication = _reflection.GeneratedProtocolMessageType('OnuDiscIndication', (_message.Message,), dict(
  DESCRIPTOR = _ONUDISCINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuDiscIndication)
  ))
_sym_db.RegisterMessage(OnuDiscIndication)

OnuIndication = _reflection.GeneratedProtocolMessageType('OnuIndication', (_message.Message,), dict(
  DESCRIPTOR = _ONUINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuIndication)
  ))
_sym_db.RegisterMessage(OnuIndication)

IntfOperIndication = _reflection.GeneratedProtocolMessageType('IntfOperIndication', (_message.Message,), dict(
  DESCRIPTOR = _INTFOPERINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.IntfOperIndication)
  ))
_sym_db.RegisterMessage(IntfOperIndication)

OmciIndication = _reflection.GeneratedProtocolMessageType('OmciIndication', (_message.Message,), dict(
  DESCRIPTOR = _OMCIINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OmciIndication)
  ))
_sym_db.RegisterMessage(OmciIndication)

PacketIndication = _reflection.GeneratedProtocolMessageType('PacketIndication', (_message.Message,), dict(
  DESCRIPTOR = _PACKETINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.PacketIndication)
  ))
_sym_db.RegisterMessage(PacketIndication)

Interface = _reflection.GeneratedProtocolMessageType('Interface', (_message.Message,), dict(
  DESCRIPTOR = _INTERFACE,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Interface)
  ))
_sym_db.RegisterMessage(Interface)

Heartbeat = _reflection.GeneratedProtocolMessageType('Heartbeat', (_message.Message,), dict(
  DESCRIPTOR = _HEARTBEAT,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Heartbeat)
  ))
_sym_db.RegisterMessage(Heartbeat)

Onu = _reflection.GeneratedProtocolMessageType('Onu', (_message.Message,), dict(
  DESCRIPTOR = _ONU,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Onu)
  ))
_sym_db.RegisterMessage(Onu)

OmciMsg = _reflection.GeneratedProtocolMessageType('OmciMsg', (_message.Message,), dict(
  DESCRIPTOR = _OMCIMSG,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OmciMsg)
  ))
_sym_db.RegisterMessage(OmciMsg)

OnuPacket = _reflection.GeneratedProtocolMessageType('OnuPacket', (_message.Message,), dict(
  DESCRIPTOR = _ONUPACKET,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuPacket)
  ))
_sym_db.RegisterMessage(OnuPacket)

UplinkPacket = _reflection.GeneratedProtocolMessageType('UplinkPacket', (_message.Message,), dict(
  DESCRIPTOR = _UPLINKPACKET,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.UplinkPacket)
  ))
_sym_db.RegisterMessage(UplinkPacket)

DeviceInfo = _reflection.GeneratedProtocolMessageType('DeviceInfo', (_message.Message,), dict(

  DeviceResourceRanges = _reflection.GeneratedProtocolMessageType('DeviceResourceRanges', (_message.Message,), dict(

    Pool = _reflection.GeneratedProtocolMessageType('Pool', (_message.Message,), dict(
      DESCRIPTOR = _DEVICEINFO_DEVICERESOURCERANGES_POOL,
      __module__ = 'openolt_pb2'
      # @@protoc_insertion_point(class_scope:openolt.DeviceInfo.DeviceResourceRanges.Pool)
      ))
    ,
    DESCRIPTOR = _DEVICEINFO_DEVICERESOURCERANGES,
    __module__ = 'openolt_pb2'
    # @@protoc_insertion_point(class_scope:openolt.DeviceInfo.DeviceResourceRanges)
    ))
  ,
  DESCRIPTOR = _DEVICEINFO,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.DeviceInfo)
  ))
_sym_db.RegisterMessage(DeviceInfo)
_sym_db.RegisterMessage(DeviceInfo.DeviceResourceRanges)
_sym_db.RegisterMessage(DeviceInfo.DeviceResourceRanges.Pool)

Classifier = _reflection.GeneratedProtocolMessageType('Classifier', (_message.Message,), dict(
  DESCRIPTOR = _CLASSIFIER,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Classifier)
  ))
_sym_db.RegisterMessage(Classifier)

ActionCmd = _reflection.GeneratedProtocolMessageType('ActionCmd', (_message.Message,), dict(
  DESCRIPTOR = _ACTIONCMD,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.ActionCmd)
  ))
_sym_db.RegisterMessage(ActionCmd)

Action = _reflection.GeneratedProtocolMessageType('Action', (_message.Message,), dict(
  DESCRIPTOR = _ACTION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Action)
  ))
_sym_db.RegisterMessage(Action)

Flow = _reflection.GeneratedProtocolMessageType('Flow', (_message.Message,), dict(
  DESCRIPTOR = _FLOW,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Flow)
  ))
_sym_db.RegisterMessage(Flow)

SerialNumber = _reflection.GeneratedProtocolMessageType('SerialNumber', (_message.Message,), dict(
  DESCRIPTOR = _SERIALNUMBER,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.SerialNumber)
  ))
_sym_db.RegisterMessage(SerialNumber)

PortStatistics = _reflection.GeneratedProtocolMessageType('PortStatistics', (_message.Message,), dict(
  DESCRIPTOR = _PORTSTATISTICS,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.PortStatistics)
  ))
_sym_db.RegisterMessage(PortStatistics)

FlowStatistics = _reflection.GeneratedProtocolMessageType('FlowStatistics', (_message.Message,), dict(
  DESCRIPTOR = _FLOWSTATISTICS,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.FlowStatistics)
  ))
_sym_db.RegisterMessage(FlowStatistics)

LosIndication = _reflection.GeneratedProtocolMessageType('LosIndication', (_message.Message,), dict(
  DESCRIPTOR = _LOSINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.LosIndication)
  ))
_sym_db.RegisterMessage(LosIndication)

DyingGaspIndication = _reflection.GeneratedProtocolMessageType('DyingGaspIndication', (_message.Message,), dict(
  DESCRIPTOR = _DYINGGASPINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.DyingGaspIndication)
  ))
_sym_db.RegisterMessage(DyingGaspIndication)

OnuAlarmIndication = _reflection.GeneratedProtocolMessageType('OnuAlarmIndication', (_message.Message,), dict(
  DESCRIPTOR = _ONUALARMINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuAlarmIndication)
  ))
_sym_db.RegisterMessage(OnuAlarmIndication)

OnuStartupFailureIndication = _reflection.GeneratedProtocolMessageType('OnuStartupFailureIndication', (_message.Message,), dict(
  DESCRIPTOR = _ONUSTARTUPFAILUREINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuStartupFailureIndication)
  ))
_sym_db.RegisterMessage(OnuStartupFailureIndication)

OnuSignalDegradeIndication = _reflection.GeneratedProtocolMessageType('OnuSignalDegradeIndication', (_message.Message,), dict(
  DESCRIPTOR = _ONUSIGNALDEGRADEINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuSignalDegradeIndication)
  ))
_sym_db.RegisterMessage(OnuSignalDegradeIndication)

OnuDriftOfWindowIndication = _reflection.GeneratedProtocolMessageType('OnuDriftOfWindowIndication', (_message.Message,), dict(
  DESCRIPTOR = _ONUDRIFTOFWINDOWINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuDriftOfWindowIndication)
  ))
_sym_db.RegisterMessage(OnuDriftOfWindowIndication)

OnuLossOfOmciChannelIndication = _reflection.GeneratedProtocolMessageType('OnuLossOfOmciChannelIndication', (_message.Message,), dict(
  DESCRIPTOR = _ONULOSSOFOMCICHANNELINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuLossOfOmciChannelIndication)
  ))
_sym_db.RegisterMessage(OnuLossOfOmciChannelIndication)

OnuSignalsFailureIndication = _reflection.GeneratedProtocolMessageType('OnuSignalsFailureIndication', (_message.Message,), dict(
  DESCRIPTOR = _ONUSIGNALSFAILUREINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuSignalsFailureIndication)
  ))
_sym_db.RegisterMessage(OnuSignalsFailureIndication)

OnuTransmissionInterferenceWarning = _reflection.GeneratedProtocolMessageType('OnuTransmissionInterferenceWarning', (_message.Message,), dict(
  DESCRIPTOR = _ONUTRANSMISSIONINTERFERENCEWARNING,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuTransmissionInterferenceWarning)
  ))
_sym_db.RegisterMessage(OnuTransmissionInterferenceWarning)

OnuActivationFailureIndication = _reflection.GeneratedProtocolMessageType('OnuActivationFailureIndication', (_message.Message,), dict(
  DESCRIPTOR = _ONUACTIVATIONFAILUREINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuActivationFailureIndication)
  ))
_sym_db.RegisterMessage(OnuActivationFailureIndication)

OnuProcessingErrorIndication = _reflection.GeneratedProtocolMessageType('OnuProcessingErrorIndication', (_message.Message,), dict(
  DESCRIPTOR = _ONUPROCESSINGERRORINDICATION,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.OnuProcessingErrorIndication)
  ))
_sym_db.RegisterMessage(OnuProcessingErrorIndication)

Scheduler = _reflection.GeneratedProtocolMessageType('Scheduler', (_message.Message,), dict(
  DESCRIPTOR = _SCHEDULER,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Scheduler)
  ))
_sym_db.RegisterMessage(Scheduler)

TrafficShapingInfo = _reflection.GeneratedProtocolMessageType('TrafficShapingInfo', (_message.Message,), dict(
  DESCRIPTOR = _TRAFFICSHAPINGINFO,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.TrafficShapingInfo)
  ))
_sym_db.RegisterMessage(TrafficShapingInfo)

Tcont = _reflection.GeneratedProtocolMessageType('Tcont', (_message.Message,), dict(
  DESCRIPTOR = _TCONT,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Tcont)
  ))
_sym_db.RegisterMessage(Tcont)

Tconts = _reflection.GeneratedProtocolMessageType('Tconts', (_message.Message,), dict(
  DESCRIPTOR = _TCONTS,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Tconts)
  ))
_sym_db.RegisterMessage(Tconts)

TailDropDiscardConfig = _reflection.GeneratedProtocolMessageType('TailDropDiscardConfig', (_message.Message,), dict(
  DESCRIPTOR = _TAILDROPDISCARDCONFIG,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.TailDropDiscardConfig)
  ))
_sym_db.RegisterMessage(TailDropDiscardConfig)

RedDiscardConfig = _reflection.GeneratedProtocolMessageType('RedDiscardConfig', (_message.Message,), dict(
  DESCRIPTOR = _REDDISCARDCONFIG,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.RedDiscardConfig)
  ))
_sym_db.RegisterMessage(RedDiscardConfig)

WRedDiscardConfig = _reflection.GeneratedProtocolMessageType('WRedDiscardConfig', (_message.Message,), dict(
  DESCRIPTOR = _WREDDISCARDCONFIG,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.WRedDiscardConfig)
  ))
_sym_db.RegisterMessage(WRedDiscardConfig)

DiscardConfig = _reflection.GeneratedProtocolMessageType('DiscardConfig', (_message.Message,), dict(
  DESCRIPTOR = _DISCARDCONFIG,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.DiscardConfig)
  ))
_sym_db.RegisterMessage(DiscardConfig)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), dict(
  DESCRIPTOR = _EMPTY,
  __module__ = 'openolt_pb2'
  # @@protoc_insertion_point(class_scope:openolt.Empty)
  ))
_sym_db.RegisterMessage(Empty)



_OPENOLT = _descriptor.ServiceDescriptor(
  name='Openolt',
  full_name='openolt.Openolt',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=7124,
  serialized_end=8571,
  methods=[
  _descriptor.MethodDescriptor(
    name='DisableOlt',
    full_name='openolt.Openolt.DisableOlt',
    index=0,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_EMPTY,
    serialized_options=_b('\202\323\344\223\002\020\"\013/v1/Disable:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ReenableOlt',
    full_name='openolt.Openolt.ReenableOlt',
    index=1,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_EMPTY,
    serialized_options=_b('\202\323\344\223\002\021\"\014/v1/Reenable:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ActivateOnu',
    full_name='openolt.Openolt.ActivateOnu',
    index=2,
    containing_service=None,
    input_type=_ONU,
    output_type=_EMPTY,
    serialized_options=_b('\202\323\344\223\002\022\"\r/v1/EnableOnu:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='DeactivateOnu',
    full_name='openolt.Openolt.DeactivateOnu',
    index=3,
    containing_service=None,
    input_type=_ONU,
    output_type=_EMPTY,
    serialized_options=_b('\202\323\344\223\002\023\"\016/v1/DisableOnu:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='DeleteOnu',
    full_name='openolt.Openolt.DeleteOnu',
    index=4,
    containing_service=None,
    input_type=_ONU,
    output_type=_EMPTY,
    serialized_options=_b('\202\323\344\223\002\022\"\r/v1/DeleteOnu:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='OmciMsgOut',
    full_name='openolt.Openolt.OmciMsgOut',
    index=5,
    containing_service=None,
    input_type=_OMCIMSG,
    output_type=_EMPTY,
    serialized_options=_b('\202\323\344\223\002\023\"\016/v1/OmciMsgOut:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='OnuPacketOut',
    full_name='openolt.Openolt.OnuPacketOut',
    index=6,
    containing_service=None,
    input_type=_ONUPACKET,
    output_type=_EMPTY,
    serialized_options=_b('\202\323\344\223\002\025\"\020/v1/OnuPacketOut:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='UplinkPacketOut',
    full_name='openolt.Openolt.UplinkPacketOut',
    index=7,
    containing_service=None,
    input_type=_UPLINKPACKET,
    output_type=_EMPTY,
    serialized_options=_b('\202\323\344\223\002\030\"\023/v1/UplinkPacketOut:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='FlowAdd',
    full_name='openolt.Openolt.FlowAdd',
    index=8,
    containing_service=None,
    input_type=_FLOW,
    output_type=_EMPTY,
    serialized_options=_b('\202\323\344\223\002\020\"\013/v1/FlowAdd:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='FlowRemove',
    full_name='openolt.Openolt.FlowRemove',
    index=9,
    containing_service=None,
    input_type=_FLOW,
    output_type=_EMPTY,
    serialized_options=_b('\202\323\344\223\002\023\"\016/v1/FlowRemove:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='HeartbeatCheck',
    full_name='openolt.Openolt.HeartbeatCheck',
    index=10,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_HEARTBEAT,
    serialized_options=_b('\202\323\344\223\002\027\"\022/v1/HeartbeatCheck:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='EnablePonIf',
    full_name='openolt.Openolt.EnablePonIf',
    index=11,
    containing_service=None,
    input_type=_INTERFACE,
    output_type=_EMPTY,
    serialized_options=_b('\202\323\344\223\002\024\"\017/v1/EnablePonIf:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='DisablePonIf',
    full_name='openolt.Openolt.DisablePonIf',
    index=12,
    containing_service=None,
    input_type=_INTERFACE,
    output_type=_EMPTY,
    serialized_options=_b('\202\323\344\223\002\025\"\020/v1/DisablePonIf:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetDeviceInfo',
    full_name='openolt.Openolt.GetDeviceInfo',
    index=13,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_DEVICEINFO,
    serialized_options=_b('\202\323\344\223\002\026\"\021/v1/GetDeviceInfo:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='Reboot',
    full_name='openolt.Openolt.Reboot',
    index=14,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_EMPTY,
    serialized_options=_b('\202\323\344\223\002\017\"\n/v1/Reboot:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='CollectStatistics',
    full_name='openolt.Openolt.CollectStatistics',
    index=15,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_EMPTY,
    serialized_options=_b('\202\323\344\223\002\032\"\025/v1/CollectStatistics:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateTconts',
    full_name='openolt.Openolt.CreateTconts',
    index=16,
    containing_service=None,
    input_type=_TCONTS,
    output_type=_EMPTY,
    serialized_options=_b('\202\323\344\223\002\025\"\020/v1/CreateTconts:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='RemoveTconts',
    full_name='openolt.Openolt.RemoveTconts',
    index=17,
    containing_service=None,
    input_type=_TCONTS,
    output_type=_EMPTY,
    serialized_options=_b('\202\323\344\223\002\025\"\020/v1/RemoveTconts:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='EnableIndication',
    full_name='openolt.Openolt.EnableIndication',
    index=18,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_INDICATION,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_OPENOLT)

DESCRIPTOR.services_by_name['Openolt'] = _OPENOLT

# @@protoc_insertion_point(module_scope)
